@@ -7,7 +7,6 @@ import contextlib
 import io
 import json
 import logging
-import os
 import subprocess
 import sys
 from time import sleep
@@ -16,6 +15,7 @@ from uuid import uuid4
 import IPython
 import botocore
 import filelock
+import sparkmagic.utils.configuration as conf
 from IPython import get_ipython
 from IPython.core.display import display
 from IPython.core.magic import (
@@ -24,8 +24,17 @@ from IPython.core.magic import (
     line_magic,
 )
 from IPython.core.magic_arguments import magic_arguments, argument, parse_argstring
-import sparkmagic.utils.configuration as conf
+
+# The class MUST call this class decorator at creation time
+# https://ipython.readthedocs.io/en/stable/config/custommagics.html
+from ipywidgets import widgets
+from requests_kerberos import REQUIRED
+from sagemaker_studio_sparkmagic_lib.emr import EMRCluster
+from sagemaker_studio_sparkmagic_lib.kerberos import write_krb_conf
+
 from ..resource.emr.auth import ClusterSessionCredentialsProvider
+from ..resource.emr.emr_client import get_emr_client
+from ..utils.arn_util import RoleArnValidator
 from ..utils.boto_client_utils import get_boto3_session
 from ..utils.constants import (
     LIBRARY_NAME,
@@ -33,11 +42,6 @@ from ..utils.constants import (
     OPERATION,
     SAGEMAKER_ANALYTICS_LOG_BASE_DIRECTORY,
 )
-from ..utils.service_metrics import (
-    records_service_metrics,
-)
-from ..utils.logging_utils import ServiceFileLogger
-
 from ..utils.emr_constants import (
     IPYTHON_KERNEL,
     MAGIC_KERNELS,
@@ -52,15 +56,11 @@ from ..utils.emr_constants import (
     AUTH_TYPE_BASIC_ACCESS,
     EMR_CONNECTION_LOG_FILE,
 )
+from ..utils.logging_utils import ServiceFileLogger
 from ..utils.resource_check import check_host_and_port, is_ssl_enabled
-from ..utils.arn_util import RoleArnValidator
-
-# The class MUST call this class decorator at creation time
-# https://ipython.readthedocs.io/en/stable/config/custommagics.html
-from ipywidgets import widgets
-from requests_kerberos import REQUIRED
-from sagemaker_studio_sparkmagic_lib.emr import EMRCluster
-from sagemaker_studio_sparkmagic_lib.kerberos import write_krb_conf
+from ..utils.service_metrics import (
+    records_service_metrics,
+)
 
 # This logger emits logs to sys.stdout, which is visible in customer's notebook in Studio
 sys_out_logger = logging.getLogger(__name__)
@@ -502,8 +502,7 @@ def _validate_emr_args(args, usage, kernel_name):
 
 
 def _initiate_emr_connect(args, boto_session, kernel_name):
-    # Needs EMR list instance group permissions
-    emr_client = boto_session.client("emr")
+    emr_client = get_emr_client(boto_session)
 
     """
     Even if assumable role arn is None, we can pass it to the EMRCluster constructor and will be handled by
@@ -539,8 +538,8 @@ def _initiate_emr_connect(args, boto_session, kernel_name):
             kernel_name=kernel_name,
         )
     elif cluster.is_krb_cluster or args.auth_type == AUTH_TYPE_BASIC_ACCESS:
-        authProvider = IpythonWidgetBasedAuthProvider()
-        authProvider.get_credentials_and_connect_to_cluster(
+        auth_provider = IpythonWidgetBasedAuthProvider()
+        auth_provider.get_credentials_and_connect_to_cluster(
             emr_client=emr_client,
             args=args,
             emr_cluster=cluster,
@@ -560,7 +559,6 @@ def _initiate_emr_connect(args, boto_session, kernel_name):
 def _initiate_connect_based_on_kernel(
     emr_client, args, emr_cluster, username, password, kernel_name
 ):
-
     # Define livy session name. session_configs are passed to livy api.
     session_name = f"{SPARK_SESSION_NAME_PREFIX}_{uuid4().hex}"
     conf.override(conf.session_configs.__name__, {"name": session_name})
@@ -590,10 +588,11 @@ def _initiate_connect_based_on_kernel(
 
 def _set_logging_config() -> None:
     """
-    Sets `disable_existing_loggers` key on the dictconfig config used by sparkmagic to create loggers.
-    By default, loading a logger via `logging.config.dictConfig` disables all existing loggers, including our loggers.
-    python doc: https://docs.python.org/3/library/logging.config.html
-    sparkmagic ref: https://github.com/jupyter-incubator/sparkmagic/blob/master/hdijupyterutils/hdijupyterutils/log.py#L13
+    Sets `disable_existing_loggers` key on the dictconfig config used by sparkmagic to create loggers. By default,
+    loading a logger via `logging.config.dictConfig` disables all existing loggers, including our loggers. python
+    doc: https://docs.python.org/3/library/logging.config.html sparkmagic ref:
+    https://github.com/jupyter-incubator/sparkmagic/blob/master/hdijupyterutils/hdijupyterutils/log.py#L13
+
     :return: None
     """
     logging_config = conf.logging_config()
@@ -708,7 +707,6 @@ class SagemakerAnalytics(Magics):
         operation = args.command[1].lower()
 
         global sagemaker_analytics_service_logger
-        kernel_name = None
 
         # emr
         if service == SERVICE.EMR:
